@@ -4,12 +4,17 @@ setClass("mle.ghypuv",
                         converged="logical",
                         error.code="numeric",
                         error.message="character",
-                        parameter.variance="matrix"),
+                        parameter.variance="matrix",
+                        fitted.params = "logical",
+                        aic = "numeric"),
          prototype(n.iter=numeric(0),
                    llh=numeric(0),
                    converged=FALSE,
                    error.code=0,
                    error.message=character(0),
-                   parameter.variance=matrix(0)),
+                   parameter.variance=matrix(0),
+                   fitted.params = logical(0),
+                   aic = numeric(0)),
          contains="ghypuv"
-)
\ No newline at end of file
+)
+
